Value

Enum Value 

pub enum Value {
    Null,
    Bool(bool),
    Number(Number),
    String(String),
    Array(Vec<Value>),
    Object(Object),
}
Represents any valid BEVE value.

This enum can represent all BEVE types and enables dynamic/schemaless deserialization of BEVE data.

Variants



Null

Represents a null value.



Bool(bool)

Represents a boolean.



Number(Number)

Represents a number (signed, unsigned, or float).



String(String)

Represents a string.



Array(Vec<Value>)

Represents an array of values.



Object(Object)

Represents an object with string or integer keys.

Implementations

Source

impl Value

pub fn is_null(&self) -> bool

Returns true if the value is null.

pub fn is_bool(&self) -> bool

Returns true if the value is a boolean.

pub fn is_number(&self) -> bool

Returns true if the value is a number.

pub fn is_string(&self) -> bool

Returns true if the value is a string.

pub fn is_array(&self) -> bool

Returns true if the value is an array.

pub fn is_object(&self) -> bool

Returns true if the value is an object.

pub fn as_bool(&self) -> Option<bool>

Returns the boolean value, if this is a Bool.

pub fn as_number(&self) -> Option<&Number>

Returns a reference to the number, if this is a Number.

pub fn as_i64(&self) -> Option<i64>

Returns the value as an i64, if applicable.

pub fn as_u64(&self) -> Option<u64>

Returns the value as a u64, if applicable.

pub fn as_f64(&self) -> Option<f64>

Returns the value as an f64, if applicable.

pub fn as_str(&self) -> Option<&str>

Returns a reference to the string, if this is a String.

pub fn as_array(&self) -> Option<&Vec<Value>>

Returns a reference to the array, if this is an Array.

pub fn as_array_mut(&mut self) -> Option<&mut Vec<Value>>

Returns a mutable reference to the array, if this is an Array.

pub fn as_object(&self) -> Option<&Object>

Returns a reference to the object, if this is an Object.

pub fn as_object_mut(&mut self) -> Option<&mut Object>

Returns a mutable reference to the object, if this is an Object.

pub fn get(&self, index: usize) -> Option<&Value>

Index into an array. Returns None if not an array or index out of bounds.

pub fn get_key(&self, key: &str) -> Option<&Value>

Index into an object by string key. Returns None if not an object or key not found.

pub fn get_int_key(&self, key: i128) -> Option<&Value>

Index into an object by integer key. Returns None if not an object or key not found.

pub fn get_uint_key(&self, key: u128) -> Option<&Value>

Index into an object by unsigned integer key. Returns None if not an object or key not found.